;BTS Install Script
;Written by Andr Gtze aka Jean Elcard, Phungus420 & James Nicholls aka NikNaks

;--------------------------------
;Include Modern UI

  !include "MUI2.nsh"

;--------------------------------
;Constants
;These are the variables you need to define for your patch

  !define NAME "MY_MOD_NAME" ;Full Name of Mod
  !define VERSION "X.X.X" ;Patch Version Number

  !define MOD_LOC "MOD_FOLDER" ;Name of Mod Folder and Patch Folder.  You must use the same name, Put your Patch in a different location and define patch path in MYCLSDIR line below
  !define SHORT_NAME "MOD_NICK" ;Abreviated mod name, example for WolfRevolution I would use WolfRev

  !define MYCLSDIR "C:\Documents and Settings\P\My Documents\My Games\Beyond the Sword\MODs\${MOD_LOC}" ;Path where your patch is, do not remove the ${MOD_LOC} entry at end of path

;You should not need to change anything below this line

  !define FIRAXIS_REG_ROOT "HKLM"
  !define FIRAXIS_REG_KEY "Software\Firaxis Games"
  !define BTSREGKEY "SOFTWARE\Firaxis Games\Sid Meier's Civilization 4 - Beyond the Sword"
  
;--------------------------------
;General

  ;Name and file

  Name "${NAME}"
  OutFile "${NAME} v${VERSION} Patch.exe" 

  ;Default installation folder
  InstallDir ""

  ;Request application privileges for Windows Vista
  RequestExecutionLevel admin

;--------------------------------
;Custom Varaiables

  Var INSTDIR1 ; Mods

  Var CurrentPage ; important for directory verification

;-------------------------------------------------------
  ;Search Registry and Look for BtS install directory
  
  Function findINSTDIR1

	Push $0
	
	#Quick BTS registry Check
	ReadRegStr $0 ${FIRAXIS_REG_ROOT} "${BTSREGKEY}" 'INSTALLDIR'
	${If} ${FileExists} $0
		StrCpy $INSTDIR1 $0
		Goto done
	${EndIf}
	
	#If fails look for other possible Registry Keys to Find the BtS folder
	# standard Civ4:BTS
	ReadRegStr $0 ${FIRAXIS_REG_ROOT} "${FIRAXIS_REG_KEY}\Sid Meier's Civilization 4 - Beyond the Sword" 'INSTALLDIR'
	${If} ${FileExists} $0
		StrCpy $INSTDIR1 $0
		Goto done
	${EndIf}

	
	# Civ4 Complete
	ReadRegStr $0 ${FIRAXIS_REG_ROOT} "${FIRAXIS_REG_KEY}\Sid Meier's Civilization 4 Complete" 'INSTALLDIR'
	${If} ${FileExists} $0
		StrCpy $0 "$0\Beyond the Sword"
		${If} ${FileExists} $0
			StrCpy $INSTDIR1 $0
			Goto done
		${EndIf}
	${EndIf}
	
	# Civ4 Gold
	ReadRegStr $0 ${FIRAXIS_REG_ROOT} "${FIRAXIS_REG_KEY}\Sid Meier's Civilization 4 Gold" 'INSTALLDIR'
	${If} ${FileExists} $0
		StrCpy $0 "$0\Beyond the Sword"
		${If} ${FileExists} $0
			StrCpy $INSTDIR1 $0
			Goto done
		${EndIf}
	${EndIf}
	
  done:
	Pop $0

  FunctionEnd
  
;--------------------------------

  ;Initialize Installer
  
  Function .onInit

    Call findINSTDIR1
    StrCpy $INSTDIR "$INSTDIR1"

  FunctionEnd

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING
  !define MUI_UNABORTWARNING
  !define MUI_FINISHPAGE_NOAUTOCLOSE
  !define MUI_UNFINISHPAGE_NOAUTOCLOSE
  !define MUI_HEADERIMAGE

  ShowInstDetails show
  ShowUninstDetails show

;--------------------------------
;Pages

  !define MUI_CUSTOMFUNCTION_GUIINIT myOnGUIInit

  ; INSTALLER PAGES:

  !define MUI_WELCOMEPAGE_TITLE "Welcome to the Setup of ${SHORT_NAME} v${VERSION} Patch"
  !define MUI_WELCOMEPAGE_TEXT "This wizard will guide you through the installation of the ${NAME} v${VERSION} patch.$\n$\n\
    Please ensure that Civilization 4 is not running while installing, \
    otherwise the installation may not work as expected.$\n$\nVersion ${VERSION} patch requires ${NAME} \
	to have been previously installed to work correctly.$\n$\n\
    Click $\"Next$\" to continue."
  !insertmacro MUI_PAGE_WELCOME

  !define MUI_COMPONENTSPAGE_SMALLDESC
  !insertmacro MUI_PAGE_COMPONENTS

  !define MUI_DIRECTORYPAGE_VARIABLE $INSTDIR1
  !define MUI_PAGE_CUSTOMFUNCTION_PRE onInitDirectoryPage1
  !define MUI_PAGE_HEADER_TEXT "${SHORT_NAME} v${VERSION}"
  !define MUI_PAGE_HEADER_SUBTEXT "Please locate your $\"Beyond the Sword$\" folder"
  !define MUI_DIRECTORYPAGE_TEXT_TOP "Setup will patch ${NAME} in the Mods folder of the folder below. $\n$\n\
    If the automatic folder detection should have failed, then type in or browse to the correct location. $\n$\n\
    Click Install to complete the patching process."
  !define MUI_DIRECTORYPAGE_TEXT_DESTINATION "Your $\"Beyond the Sword$\" folder:"
  !insertmacro MUI_PAGE_DIRECTORY

  !insertmacro MUI_PAGE_INSTFILES

  !define MUI_FINISHPAGE_RUN "$INSTDIR1\Civ4BeyondSword.exe"
    !define MUI_FINISHPAGE_RUN_PARAMETERS "mod=\${MOD_LOC}"
    !define MUI_FINISHPAGE_RUN_NOTCHECKED
  !insertmacro MUI_PAGE_FINISH

    ;UN INSTALLER PAGES Removed
;--------------------------------
;Languages

  !insertmacro MUI_LANGUAGE "English"

  LangString DESC_Section1 ${LANG_ENGLISH} "Patches ${NAME} to ${VERSION}."

;--------------------------------
;Installer Sections
    ;Patch files
  Section /o "${MOD_LOC}" Section1
    SectionIn RO
    SetOutPath "$INSTDIR1\Mods\${MOD_LOC}"
    File /r "${MYCLSDIR}\*.*"
  SectionEnd

  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${Section1}  $(DESC_Section1)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------

;Installer Functions

  Function myOnGUIInit
    SectionGetFlags ${Section1} $0
    IntOp $R0 $0 | ${SF_SELECTED}
    SectionSetFlags ${Section1} $R0
  FunctionEnd

  Function .onVerifyInstDir
    StrCmp $CurrentPage "DirectoryPage1" check1 valid
    check1:
      IfFileExists "$INSTDIR1\Civ4BeyondSword.exe" valid invalid
    valid:
      Return
    invalid:
      Abort
  FunctionEnd

  Function onInitDirectoryPage1
    StrCpy $CurrentPage "DirectoryPage1"
    ;Section 1 selected?
    SectionGetFlags ${Section1} $0
    IntOp $R0 $0 & ${SF_SELECTED}
    IntCmp $R0 ${SF_SELECTED} checkRegEntry
      Abort ;skip page
    checkRegEntry:
      StrCmp $INSTDIR "" 0 checkDefaultLocation
        StrCpy $INSTDIR1 "" ;we know nothing
        Return
      checkDefaultLocation:
          StrCpy $INSTDIR1 "$INSTDIR" ;found it!
  FunctionEnd
;--------------------------------